@@ -24,7 +24,6 @@
 #include "player.h"
 
 #include "tron.h"
-#include "snakepart.h"
 #include "settings.h"
 
 #include "ksnakeduel_debug.h"
@@ -349,7 +348,7 @@ void Player::movePlayer()
 		if (m_playField->getObjectAt(newX, newY)->getObjectType() == ObjectType::Item)
 		{
 			//qCDebug(KSNAKEDUEL_LOG) << "Boom!";
-			emit fetchedItem(m_playerNumber, newX, newY);
+			Q_EMIT fetchedItem(m_playerNumber, newX, newY);
 		}
 
 		newHead.generateSVGName();
